pub struct SavedAsset<'a, 'b, A>where
A: Asset,{ /* private fields */ }Expand description
An Asset (and any labeled “sub assets”) intended to be saved.
Implementations
Sourceimpl<'a, 'b, A> SavedAsset<'a, 'b, A>where
A: Asset,
impl<'a, 'b, A> SavedAsset<'a, 'b, A>where
A: Asset,
Sourcepub fn from_loaded(
asset: &'a ErasedLoadedAsset,
) -> Option<SavedAsset<'a, 'b, A>>
pub fn from_loaded( asset: &'a ErasedLoadedAsset, ) -> Option<SavedAsset<'a, 'b, A>>
Creates a new SavedAsset from asset if its internal value matches A.
Sourcepub fn from_transformed(asset: &'a TransformedAsset<A>) -> SavedAsset<'a, 'b, A>
pub fn from_transformed(asset: &'a TransformedAsset<A>) -> SavedAsset<'a, 'b, A>
Creates a new SavedAsset from the a TransformedAsset
Sourcepub fn from_asset(value: &'a A) -> SavedAsset<'a, 'b, A>
pub fn from_asset(value: &'a A) -> SavedAsset<'a, 'b, A>
Creates a new SavedAsset holding only the provided value with no labeled assets.
Sourcepub fn upcast(self) -> ErasedSavedAsset<'a, 'a>where
'b: 'a,
pub fn upcast(self) -> ErasedSavedAsset<'a, 'a>where
'b: 'a,
Casts this typed asset into its type-erased form.
Sourcepub fn get_labeled<B>(
&self,
label: impl AsRef<str>,
) -> Option<SavedAsset<'a, '_, B>>where
B: Asset,
pub fn get_labeled<B>(
&self,
label: impl AsRef<str>,
) -> Option<SavedAsset<'a, '_, B>>where
B: Asset,
Returns the labeled asset, if it exists and matches this type.
Sourcepub fn get_erased_labeled(
&self,
label: impl AsRef<str>,
) -> Option<&ErasedSavedAsset<'a, '_>>
pub fn get_erased_labeled( &self, label: impl AsRef<str>, ) -> Option<&ErasedSavedAsset<'a, '_>>
Returns the type-erased labeled asset, if it exists and matches this type.
Sourcepub fn get_labeled_by_id<B>(
&self,
id: impl Into<AssetId<B>>,
) -> Option<SavedAsset<'a, '_, B>>where
B: Asset,
pub fn get_labeled_by_id<B>(
&self,
id: impl Into<AssetId<B>>,
) -> Option<SavedAsset<'a, '_, B>>where
B: Asset,
Returns the labeled asset given its asset ID if it exists and matches the type.
This can be used to get the asset from its handle since &Handle implements
Into<AssetId<B>>.
Sourcepub fn get_erased_labeled_by_id(
&self,
id: impl Into<UntypedAssetId>,
) -> Option<&ErasedSavedAsset<'a, '_>>
pub fn get_erased_labeled_by_id( &self, id: impl Into<UntypedAssetId>, ) -> Option<&ErasedSavedAsset<'a, '_>>
Returns the type-erased labeled asset given its asset ID if it exists.
This can be used to get the asset from its handle since &UntypedHandle implements
Into<UntypedAssetId>.
Sourcepub fn get_untyped_handle(
&self,
label: impl AsRef<str>,
) -> Option<UntypedHandle>
pub fn get_untyped_handle( &self, label: impl AsRef<str>, ) -> Option<UntypedHandle>
Returns the UntypedHandle of the labeled asset with the provided ‘label’, if it exists.
Sourcepub fn get_handle<B>(&self, label: impl AsRef<str>) -> Option<Handle<B>>where
B: Asset,
pub fn get_handle<B>(&self, label: impl AsRef<str>) -> Option<Handle<B>>where
B: Asset,
Returns the Handle of the labeled asset with the provided ‘label’, if it exists and is an asset of type B
Sourcepub fn iter_labels(&self) -> impl Iterator<Item = &str>
pub fn iter_labels(&self) -> impl Iterator<Item = &str>
Iterate over all labels for “labeled assets” in the loaded asset